@@ -5,7 +5,7 @@ from typing import List, Union
 from pathlib import Path
 
 
-__version__ = "2022.5.27.1"
+__version__ = "2022.6.2.1"
 log_format = logging.Formatter(
     "[%(asctime)s] %(filename)s/%(lineno)s/%(funcName)s/%(levelname)s: %(message)s"
 )
@@ -114,6 +114,8 @@ def configure_logger(
                     handler.setLevel(level)
                     logger.addHandler(handler)
                     log_file_list.append(str(handler.baseFilename))
+            elif isinstance(handler, logging.Handler):
+                logger.warning(f"忽略日志Handler：{handler}")
             else:
                 raise TypeError(f"类型错误，预期为{logging.Handler}类型，实际为{type(handler)}类型")
 
